-- 武库分解
Lua_CardResolveWindow = class("Lua_CardResolveWindow", Lua_SecondSizeWindow)
function Lua_CardResolveWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CardResolveWindow";
	self.skinName = "CardResolveWindow_skin";
	self.titleText = LanUtil.getValue(128200);
end

function Lua_CardResolveWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.resolveArr = Array();

	self.recordsList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 1030, 440));
	self.recordsList:setListCell(Lua_CardResolveItem, 232, 210, 5);
	self.recordsList:setLocation(16, 16, 0);
	self.recordsList:setSubPos(-25, 0, 0);

	self.help:addClickFuntion(self, self.onHelpClick);
	self.resolveBtn:addClickFuntion(self, self.onResolveClick);
	self.subBtn:addClickFuntion(self, self.onSelectCardClick); -- 选择分解类型
	self.selectCheckBox:addBoxChange(self, self.onSelectBoxClick); -- 自动分解选择
	
	local selectType = DataCenter.cardData.select_card;
	if selectType == nil then
		selectType = 2;
	end
	self:setSelectType(selectType);

	self:onUpdatePackInfo();
	self:onResolveCardData();

	self:addLuaEvent("IS_SELCET", self, self.onSelectInfo)
	self:addLuaEvent("RESOLVE_CARD_INFO", self, self.onUpdatePackInfo)--分解灵纹后刷新界面
	self:addLuaEvent("PACK_CARD_UPDATE", self, self.onUpdatePackInfo) -- 背包获取新卡牌后刷新界面
	self:addLuaEvent("PACK_CARD_UPDATE", self, self.onResolveCardData)-- 背包获取新卡牌更新分解数据
end

function Lua_CardResolveWindow:onSelectCardClick(go)
	local dragData = {};
	dragData.datas = Array();
	dragData.datas:add(LanUtil.getValue(110160));
	dragData.datas:add(LanUtil.getValue(124424));
	dragData.datas:add(LanUtil.getValue(124425));
	dragData.datas:add(LanUtil.getValue(124426));
	dragData.datas:add(LanUtil.getValue(124427));
	dragData.offsetX = -440;
	dragData.offsetY = -129;
	dragData.height = 179;
	dragData.callBackOwner = self;
	dragData.callBack = self.onDragDownCallBack;
	dragData.selected = self.selectType;
	Lua_WindowUtil.openWin("Lua_DragDownWindow", nil, dragData);
end

function Lua_CardResolveWindow:onDragDownCallBack(val)
	DataCenter.cardData.select_card = val;
	self:setSelectType(val);
	self:onUpdatePackInfo(); -- 背包数据
	self:onResolveCardData();
end

function Lua_CardResolveWindow:setSelectType(val)
	self.selectType = val;

	if val == 1 then -- 无
		self.subTxt.text = LanUtil.getValue(128211);
	elseif val == 2 then -- 蓝色
		self.subTxt.text = LanUtil.getValue(124418);
	elseif val == 3 then -- 紫色
		self.subTxt.text = LanUtil.getValue(124419);
	elseif val == 4 then -- 橙色
		self.subTxt.text = LanUtil.getValue(124420);
	elseif val == 5 then -- 红色
		self.subTxt.text = LanUtil.getValue(124421);
	end
end

-- 分解数据
function Lua_CardResolveWindow:onResolveCardData()
	local obj;
	self.resolveArr:clear();
	for i = 1, self.resolveList:getSize() do
		obj = self.resolveList[i];
		if obj.isSelect == true then
			self.resolveArr:add({
				id = obj.vo.id,
				index = obj.vo.index,
				type = obj.vo.card_type,
				color = obj.vo.color,
				decompose = obj.vo.decompose
			});
		end
	end

	if self.resolveArr:getSize() > 0  then
		local resolveNum = DataCenter.cardUtil:cardResolveNum(self.resolveArr);
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(128203), tostring(DataCenter.cardData.fragment), tostring(resolveNum));
	else
		self.resolveTxt.text = LanUtil.formateStr(LanUtil.getValue(128212), tostring(DataCenter.cardData.fragment));
	end

	self.selectCheckBox.seleted = DataCenter.cardData.isAutoCardResolve ~= 0;

	self:updateCardResolveRed() -- 红点显示
end

-- 点击 单个灵纹 刷新界面
function Lua_CardResolveWindow:onSelectInfo()
	self:onResolveCardData();
	self:updateSelect();
end

-- 背包数据
function Lua_CardResolveWindow:onUpdatePackInfo()
	local bagData = DataCenter.packData:getBagType(Lua_PackData.CARD_PACK);
	local arr = bagData:getBagAllData();
	local len = arr:getSize();
	self.resolveList = Array();
	for i = 1, len do
		for j = i + 1, len do
			if not self:sortFun(arr[i], arr[j]) then
				local temp = arr[i];
				arr[i] = arr[j];
				arr[j] = temp;
			end
		end
		self.resolveList:add({vo = arr[i], isSelect = self:checkSelect(arr[i])});
	end
	self.recordsList:setLuaArrayData(self.resolveList, false);
end

function Lua_CardResolveWindow:sortFun(a, b)
	if a == nil or b == nil then
		return false;
	end

	if a.card_type ~= 0 and b.card_type == 0 then
		return true;
	elseif a.card_type == 0 and a.card_type == 0 then
		if a.color > b.color then
			return true;
		end
	elseif a.card_type ~= 0 and b.card_type ~= 0 then
		if a.color > b.color then
			return true;
		elseif a.color == b.color then
			if a.card_level > b.card_level then
				return true;
			end
		end
	end
	return false;
end

function Lua_CardResolveWindow:checkSelect(vo)
	if vo == nil then
		return false;
	end

	if self.selectType == 1 then
		return false;
	elseif (self.selectType == 2 and vo.color <= 2) or vo.card_type == 0 then
		return true;
	elseif (self.selectType == 3 and vo.color <= 3) or vo.card_type == 0 then
		return true;
	elseif (self.selectType == 4 and vo.color <= 4) or vo.card_type == 0 then
		return true;
	elseif (self.selectType == 5 and vo.color <= 5) or vo.card_type == 0 then
		return true;
	end
	return false;
end


function Lua_CardResolveWindow:onResolveTipsClick()
	Lua_WindowUtil.openWin("Lua_TipsWindow", nil, {owner = self, des = LanUtil.getValue(128213), type = 1, subFun = self.onSubCallback});
end

function Lua_CardResolveWindow:onResolveClick()
	local isResolve = false;
	local len = self.resolveArr:getSize()
	if len > 0 then
		for i = 1, len do
			if self.resolveArr[i].type ~= 0 then
				if self.resolveArr[i].color >= 4 then
					isResolve = true;
				end
			end
		end

		if isResolve == true then
			self:onResolveTipsClick();
		else
			self:onSubCallback();
		end
	else
		OperateAlert.show(LanUtil.getValue(128215));
	end
end

function Lua_CardResolveWindow:onSubCallback()
	Lua_ProxyManager.getProxy("Lua_CardProxy"):sResolveCard(self.resolveArr);
	if self.resolveList ~= nil then
		self.resolveList:clear();
	end

	if self.resolveArr ~= nil then
		self.resolveArr:clear();
	end
end

function Lua_CardResolveWindow:onSelectBoxClick(state)
	if state == true then
		Lua_ProxyManager.getProxy("Lua_CardProxy"):sAutoResolveCard(1);
		DataCenter.cardData.isAutoCardResolve = 1;
	else
		Lua_ProxyManager.getProxy("Lua_CardProxy"):sAutoResolveCard(0);
		DataCenter.cardData.isAutoCardResolve = 0;
	end
end

function Lua_CardResolveWindow:updateSelect()
	if self.recordsList ~= nil then
		local arr = self.recordsList.showList;
		for i = 1, arr:getSize() do
			arr[i]:updateSelect();
		end
	end
end

-- 红点更新
function Lua_CardResolveWindow:updateCardResolveRed()
	local isShowResolveRed = DataCenter.cardData:isShowCardResolveRed();
	if isShowResolveRed == true then
		self:showRedDot(true); -- 分解红点显示
	else
		self:showRedDot(false);
	end
end

-- 红点显示
function Lua_CardResolveWindow:showRedDot(val)
	if val == true then
		if self._redDotIcon == nil then
			self._redDotIcon = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_hongdian", 528, -238, 0, 0);
			self._redDotIcon.name = "redDot";
			self._redDotIcon:setDepth(7);
		end
		self._redDotIcon:setEnable(true);
	else
		if self._redDotIcon ~= nil then
			self._redDotIcon:setEnable(false);
		end
	end
end

function Lua_CardResolveWindow:onHelpClick()
	Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_AUTO, LanUtil.getValue(128210));
end

function Lua_CardResolveWindow:dispose()
	if self.recordsList ~= nil then
		self.recordsList:dispose();
		self.recordsList = nil;
	end
	if self.resolveList ~= nil then
		self.resolveList:clear();
		self.resolveList = nil; 
	end
	if self.resolveArr ~= nil then
		self.resolveArr:clear();
		self.resolveArr = nil; 
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_CardResolveItem = class("Lua_CardResolveItem", Lua_ListCell);
function Lua_CardResolveItem:ctor(p)
	self:superCall("ctor", p, "CardResolveItem_skin");
end

function Lua_CardResolveItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_CardResolveItem:setData(data)
	self.data = data;
	self.vo = data.vo;

	self.card_lvl.text = self.vo.card_level;
	self.card_name.text = self.vo.name;

	self.card_bg:setAltas("wuku_atlas", "ui_wuku_bg_0"..(self.vo.color - 1));

	self.card_icon:SetDimensions(0, 0);
	self.card_icon:setUrl(self.vo.cardAtlas);
	self.card_icon:setScale(0.75, 0.75);

	if self.vo.card_type == 0 then
		self.card_name.fontSize = 20;
	else
		self.card_name.fontSize = 22;
	end

	self.bind:setEnable(self.vo.bind ~= 0);

	self:updateSelect();
end

function Lua_CardResolveItem:updateSelect()
	if self.data.isSelect == true then
		self.show:setEnable(true);
		self.card_bg:setGray(true);
		self.card_icon:setGray(true);
	else
		self.show:setEnable(false);
		self.card_bg:setGray(false);
		self.card_icon:setGray(false);
	end
end

function Lua_CardResolveItem:onPlayerSoundClick(go)
	if self.data.isSelect == true then
		self.data.isSelect = false;
	else
		self.data.isSelect = true;
	end
	Lua_MsgUtil.callFunc("IS_SELCET");
end

function Lua_CardResolveItem:dispose()
	self:superCall("dispose");
end